# auto-wing

![](auto-wing.png)

> auto-wing is a tool that uses LLM to assist automated testing, give your automated testing wings.

auto-wing是一个利用LLM辅助自动化测试的工具, 为你的自动化测试插上翅膀。


### Features

⭐ 支持多种操作：`ai_action`、`ai_query`、`ai_assert`等。

⭐ 支持多模型：`openai`、`qwen` 和 `deepseek`。

⭐ 支持 `playwright`、`selenium`等。

⭐ 方便的和现有自动化项目集成。

### 安装
